@@ -8,7 +8,7 @@
 #' The function assumes that each column of the matrix is associated with a unique geographical location or 
 #' that each RasterLayer has exactly the same geographical extent and resolution. 
 #' @param R An integer specifying the number of iterations. A larger \emph{R} is required when the sample size is large.
-#' R = sample size x 200 is often sufficient (e.g. R = 2000 for a sample size 10).
+#' R > sample size x 100 is recommended (e.g. R > 1000 for a sample size 10).
 #' @param method The overlap quantification method. 
 #' "HR" is for the proportion of an individual's home range overlapped by the known habitats of other individuals. 
 #' "PHR" is for the probability of an individual to be within the known habitats of other individuals. 
@@ -18,7 +18,6 @@
 #' @param percent An integer specifying the percent volume of each UD to be considered in the analysis. 
 #' @param quantiles A vector or a number to specify the quantiles to be calculated in the summary of the results. 
 #' @importFrom raster values
-#' @importFrom plyr rbind.fill
 #' @importFrom stats aggregate sd
 #' @importFrom utils setTxtProgressBar txtProgressBar
 #' @export
@@ -32,24 +31,25 @@
 #' \emph{Methods in Ecology and Evolution} 12(2):288-297 \doi{10.1111/2041-210X.13506}
 #' @references Fieberg J & Kochanny CO (2005) Quantifying home-range overlap: The importance of the utilization distribution. 
 #' \emph{The Journal of Wildlife Management}, 69(4), 1346–1359. \doi{10.2193/0022-541x(2005)69[1346:Qhotio]2.0.Co;2}
+#' @seealso \code{\link{combn_overlap}}, \code{\link{boot_area}}
 #' @examples
 #' \dontrun{
 #' 
-#' #1 Utilisation uistributions of flatback turtles (n = 29).
+#' #1 Utilisation uistributions of flatback turtles (n = 15).
 #' data(ud_matrix)
 #' 
-#' #2 Calculate overlap probability from 6000 random permutation.
-#' overlap <- boot_overlap(ud_matrix, R = 6000, method = "PHR")
+#' #2 Calculate overlap probability from 2000 random permutation.
+#' overlap <- boot_overlap(ud_matrix, R = 2000, method = "PHR")
 #' 
 #' #3 Find the minimum sample size required to estimate the general distribution.
-#' a <- asymptote(overlap)
+#' a <- asymptote(overlap, upper.degree = 10, estimator = 'glm', family = binomial)
 #' 
 #' #4 Plot the mean probability and rational function fit relative to the sample sizes.
-#' ggplot(data = overlap$summary)+
-#'   geom_point(aes(x = N, y = mu), alpha = 0.5) + 
-#'   geom_path(data = a$results, aes(x = x, y = ys)) + 
-#'   geom_vline(xintercept = a$min.n, linetype = 2) +
-#'   labs(x = "N", y = "Overlap probability")
+#' ggplot(data = a$results, aes(x = x))+
+#'   geom_pointrange(aes(y = y, ymin = y_lwr, ymax = y_upr)) + 
+#'   geom_hline(yintercept = a$h.asymptote*0.95, linetype = 2) +
+#'   scale_x_continuous(breaks = seq(0, 15, 3), limits = c(2,15), name = "Animals tracked (n)") +
+#'   scale_y_continuous(limits = c(0.5,1), name = "Overlap probability")
 #' }
 
 
@@ -90,15 +90,21 @@ boot_overlap <- function(data, R = 1000, method = "PHR", percent = 100, quantile
   l <- lapply(1:nrow(dens_all), function(x) {dens_all[x,] / row_sum[x]})
   dens_all <- do.call(rbind, l)
   
-  #### Areas under xx% volume
-  # if(method == "HR"){
-  #   l <- lapply(1:nrow(dens_all), function(x) percent_vol(dens_all[x,], percent))
-  #   dens_all <- do.call(rbind, l)
-  # }
   
-  #### Quantify overlap
-  overlap_index <- function(i){
-    
+  #### empty vectors to save results
+  nR <- (nrow(dens_all) - 1) * R
+  iteration <- rep(0, nR)
+  N <- rep(0, nR)
+  overlap <- rep(0, nR)
+  new_data <- rep('', nR)
+  existing_data <- rep('', nR)
+
+  
+  #### Quantify overlap for R times
+  rn <- 0
+  pb <- utils::txtProgressBar(min = 0, max = R, width = 50, style = 3)
+  
+  for(i in 1:R){
     ## Random order of the input layers
     n <- sample(nrow(dens_all), nrow(dens_all))
     
@@ -106,74 +112,69 @@ boot_overlap <- function(data, R = 1000, method = "PHR", percent = 100, quantile
     dens_a <- dens_all[n[1],]
     
     ## Overlap between dens_a and collective UD
-    index.list <- lapply(2:nrow(dens_all), function(k){
+    for(k in 2:nrow(dens_all)){
+      rn <- rn + 1
       
-        ## combined (mean) ud of the subsets
-        dens_sub <- dens_all[n[2:k],]
-        
-        ## Areas under xx% volume (only for collective areas)
-        if(percent < 100){
-          if(is.matrix(dens_sub)){
-            l <- lapply(1:nrow(dens_sub), function(x) percent_vol(dens_sub[x,], percent))
-            dens_sub <- do.call(rbind, l)
-          } else {
-            dens_sub <- percent_vol(dens_sub, percent)
-          }
-        } 
-        
+      ## combined (mean) ud of the subsets
+      dens_sub <- dens_all[n[2:k],]
+      
+      ## Areas under xx% volume (only for collective areas)
+      if(percent < 100){
         if(is.matrix(dens_sub)){
-          if(method %in% c("HR", "PHR")){
-            dens_sub <- colSums(dens_sub)
-          } else {
-            dens_sub <- colMeans(dens_sub)
-          }
+          l <- lapply(1:nrow(dens_sub), function(x) percent_vol(dens_sub[x,], percent))
+          dens_sub <- do.call(rbind, l)
+        } else {
+          dens_sub <- percent_vol(dens_sub, percent)
         }
-
-        ## Calculate overlaps
-        if(method == "HR") {
-          goi <- which(dens_a*dens_sub > 0)
-          index <- length(dens_a[goi]) / length(dens_a[dens_a > 0])
-        } else if(method == "PHR") {
-          goi <- which(dens_a*dens_sub > 0)
-          index <- sum(dens_a[goi])
-        } else if (method == "VI"){
-          goi <- which(dens_a*dens_sub > 0)
-          min.val <- pmin(dens_a[goi], dens_sub[goi])
-          index <- sum(min.val)
-        } else if(method == "BA") {
-          index <- sum(sqrt(dens_a*dens_sub))
-        } else if(method == "UDOI") {
-          goi <- which(dens_a*dens_sub > 0)
-          val <- dens_a[goi]*dens_sub[goi]
-          index <- sum(val) * length(goi)
-        }
-    
-    ## Results
-    df <- data.frame(matrix(c(i, k, index, nam[n[1]], c(nam[n[2:k]])), nrow = 1))
-    df[,1:ncol(df)] <- lapply(df[,1:ncol(df)], as.character)
-    df[,1:3] <- lapply(df[,1:3], as.numeric)
-    return(df)
-  })
-    
-    index.df <- plyr::rbind.fill(index.list)
-    
+      } 
       
+      if(is.matrix(dens_sub)){
+        if(method %in% c("HR", "PHR")){
+          dens_sub <- colSums(dens_sub)
+        } else {
+          dens_sub <- colMeans(dens_sub)
+        }
+      }
+      
+      ## Calculate overlaps
+      if(method == "HR") {
+        goi <- which(dens_a*dens_sub > 0)
+        index <- length(dens_a[goi]) / length(dens_a[dens_a > 0])
+      } else if(method == "PHR") {
+        goi <- which(dens_a*dens_sub > 0)
+        index <- sum(dens_a[goi])
+      } else if (method == "VI"){
+        goi <- which(dens_a*dens_sub > 0)
+        min.val <- pmin(dens_a[goi], dens_sub[goi])
+        index <- sum(min.val)
+      } else if(method == "BA") {
+        index <- sum(sqrt(dens_a*dens_sub))
+      } else if(method == "UDOI") {
+        goi <- which(dens_a*dens_sub > 0)
+        val <- dens_a[goi]*dens_sub[goi]
+        index <- sum(val) * length(goi)
+      }
+      
+      ## Results
+      iteration[rn] <- i
+      N[rn] <- k
+      overlap[rn] <- index
+      new_data[rn] <- nam[n[1]]
+      existing_data[rn] <- paste(nam[n[2:k]], collapse=',')
+    }
+    
+
     #### progress bar
     Sys.sleep(0.1)
     utils::setTxtProgressBar(pb, i)
-    
-    #### Output
-    return(index.df)
   }
   
-  #### Run overlap_index function for R times
-  pb <- utils::txtProgressBar(min = 0, max = R, width = 50, style = 3)
-  overlap_list <- lapply(1:R, overlap_index)
   close(pb)
   
-  overlap_df <- plyr::rbind.fill(overlap_list)
-  colnames(overlap_df) <- c('iteration', 'N', 'overlap', paste0('id', 1:(ncol(overlap_df)-3)))
-  
+  # id_df <- as.data.frame(do.call(cbind, id_list))
+  overlap_df <- data.frame(iteration, N, overlap, new_data, existing_data)
+
+
   #### Summary stats
   summary.data <- stats::aggregate(overlap ~ N, data = overlap_df, FUN = function(x) {
     c(mu = mean(x),
